# Models

## RecentHistory

### Overview

#### Definition of a sample

x: (pv_id, timestamp at which we are making the prediction)
y: [power for many horizons]

#### Features used

* Recent PV history (last 30 min + yesterday at prediction time).
* NWP at the time of prediction and for the location of the PV.
* `pvlib`'s theoretical models (used as features and to normalize everything).

### Methodology

1. We infer the `tilt`/`orientation`/`capacity` of each PV (see infer_pv_metadata.py), finding the best
   fit with respect to pvlib's theoretical values. Our `capacity` is defined as the factor that we need to
   multiply to pvlib's theoretical `poa_global` to get the power generated by the PV. This means
   the units of `capacity` are `kW / poa_global`.
2. Before training, we normalize the output by our inferred `capacity` and by `pvlib`'s theoretical
   `poa_global`. **This makes patterns easier to learn for the regressor, as two different PVs with in
   the same conditions (same `poa_global`) will have the same output values.** In inference we only
   need to multiply the predictions by their `capacity` and pvlib's `poa_global`. This also means
   that we don't need to use the model's capacity (note: model capacity != PV capacity !) to learn
   what happens at night: their `poa_global` will be 0.0 anyway.
3. Currently we use an ensemble of decision trees ([sklearn's HistGradientBoostingRegressor][hist])
   as the regressor. Instead of the regressor having multiple outputs (one for each
   horizon), we flatten all the horizons in as many samples (this is done seamlessly in our
   RandomForest regressor class). We add the horizon index as a feature; for a given horizon, we
   only pass the features related to that horizon (e.g. NWP features closest to that horizon); we
   add any feature common to all horizons (e.g. the power for the last 30 minutes).


[hist]: https://scikit-learn.org/stable/modules/generated/sklearn.ensemble.HistGradientBoostingRegressor.html
